google_api_cloud_tasks v0.4.0 GoogleApi.CloudTasks.V2.Model.Task View Source
A unit of scheduled work.
Attributes
appEngineHttpRequest(type:GoogleApi.CloudTasks.V2.Model.AppEngineHttpRequest.t, default:nil) - HTTP request that is sent to the App Engine app handler.An App Engine task is a task that has AppEngineHttpRequest set.
createTime(type:DateTime.t, default:nil) - Output only. The time that the task was created.create_timewill be truncated to the nearest second.dispatchCount(type:integer(), default:nil) - Output only. The number of attempts dispatched.This count includes attempts which have been dispatched but haven't received a response.
dispatchDeadline(type:String.t, default:nil) - The deadline for requests sent to the worker. If the worker does not respond by this deadline then the request is cancelled and the attempt is marked as aDEADLINE_EXCEEDEDfailure. Cloud Tasks will retry the task according to the RetryConfig.Note that when the request is cancelled, Cloud Tasks will stop listing for the response, but whether the worker stops processing depends on the worker. For example, if the worker is stuck, it may not react to cancelled requests.
The default and maximum values depend on the type of request:
- For App Engine tasks, 0 indicates that the
request has the default deadline. The default deadline depends on the
scaling
type
of the service: 10 minutes for standard apps with automatic scaling, 24
hours for standard apps with manual and basic scaling, and 60 minutes for
flex apps. If the request deadline is set, it must be in the interval [15
seconds, 24 hours 15 seconds]. Regardless of the task's
dispatch_deadline, the app handler will not run for longer than than the service's timeout. We recommend setting thedispatch_deadlineto at most a few seconds more than the app handler's timeout. For more information see Timeouts.
dispatch_deadlinewill be truncated to the nearest millisecond. The deadline is an approximate deadline.- For App Engine tasks, 0 indicates that the
request has the default deadline. The default deadline depends on the
scaling
type
of the service: 10 minutes for standard apps with automatic scaling, 24
hours for standard apps with manual and basic scaling, and 60 minutes for
flex apps. If the request deadline is set, it must be in the interval [15
seconds, 24 hours 15 seconds]. Regardless of the task's
firstAttempt(type:GoogleApi.CloudTasks.V2.Model.Attempt.t, default:nil) - Output only. The status of the task's first attempt.Only dispatch_time will be set. The other Attempt information is not retained by Cloud Tasks.
lastAttempt(type:GoogleApi.CloudTasks.V2.Model.Attempt.t, default:nil) - Output only. The status of the task's last attempt.name(type:String.t, default:nil) - Optionally caller-specified in CreateTask.The task name.
The task name must have the following format:
projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks/TASK_IDPROJECT_IDcan contain letters ([A-Za-z]), numbers ([0-9]), hyphens (-), colons (:), or periods (.). For more information, see Identifying projectsLOCATION_IDis the canonical ID for the task's location. The list of available locations can be obtained by calling ListLocations. For more information, see https://cloud.google.com/about/locations/.QUEUE_IDcan contain letters ([A-Za-z]), numbers ([0-9]), or hyphens (-). The maximum length is 100 characters.TASK_IDcan contain only letters ([A-Za-z]), numbers ([0-9]), hyphens (-), or underscores (_). The maximum length is 500 characters.
responseCount(type:integer(), default:nil) - Output only. The number of attempts which have received a response.scheduleTime(type:DateTime.t, default:nil) - The time when the task is scheduled to be attempted or retried.schedule_timewill be truncated to the nearest microsecond.view(type:String.t, default:nil) - Output only. The view specifies which subset of the Task has been returned.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
t()
View Sourcet() :: %GoogleApi.CloudTasks.V2.Model.Task{
appEngineHttpRequest: GoogleApi.CloudTasks.V2.Model.AppEngineHttpRequest.t(),
createTime: DateTime.t(),
dispatchCount: integer(),
dispatchDeadline: String.t(),
firstAttempt: GoogleApi.CloudTasks.V2.Model.Attempt.t(),
lastAttempt: GoogleApi.CloudTasks.V2.Model.Attempt.t(),
name: String.t(),
responseCount: integer(),
scheduleTime: DateTime.t(),
view: String.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.