google_api_cloud_tasks v0.4.0 GoogleApi.CloudTasks.V2beta2.Model.AttemptStatus View Source
The status of a task attempt.
Attributes
dispatchTime(type:DateTime.t, default:nil) - Output only. The time that this attempt was dispatched.dispatch_timewill be truncated to the nearest microsecond.responseStatus(type:GoogleApi.CloudTasks.V2beta2.Model.Status.t, default:nil) - Output only. The response from the target for this attempt.If the task has not been attempted or the task is currently running then the response status is unset.
responseTime(type:DateTime.t, default:nil) - Output only. The time that this attempt response was received.response_timewill be truncated to the nearest microsecond.scheduleTime(type:DateTime.t, default:nil) - Output only. The time that this attempt was scheduled.schedule_timewill be truncated to the nearest microsecond.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
t()
View Sourcet() :: %GoogleApi.CloudTasks.V2beta2.Model.AttemptStatus{
dispatchTime: DateTime.t(),
responseStatus: GoogleApi.CloudTasks.V2beta2.Model.Status.t(),
responseTime: DateTime.t(),
scheduleTime: DateTime.t()
}
Link to this section Functions
Unwrap a decoded JSON object into its complex fields.